ProviderInfo class
Constructors
-
ProviderInfo({RiverpodCraftOptions options = RiverpodCraftOptions.empty, required String name, required String dataType, required bool isKeepAlive, required ProviderType type, required List<
ParameterInfo> params, required List<Command> commands, bool isFunctional = false, String? functionName, bool requiresRef = false, bool isSettable = false, bool isNoInit = false, bool hasPagedMapper = false, List<String> allProviderVarNames = const [], List<PublicMethod> publicMethods = const [], String pageKeyType = 'int'}) -
const
Properties
-
allProviderVarNames
→ List<
String> -
final
-
commands
→ List<
Command> -
final
- dataType → String
-
no setter
- errorType → String
-
no setter
- facadeClassName → String
-
no setter
- firstPageKey → String?
-
The initial page key, derived from pageKeyType:
int→1, a nullable type →null. Other (non-int, non-nullable) types are unsupported and returnnullhere — the developer must use a nullable key and the generator leavesfirstPageKeyabstract for them to provide.no setter - functionName → String?
-
final
- hasArg → bool
-
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- hasPagedMapper → bool
-
final
- isFunctional → bool
-
final
- isKeepAlive → bool
-
final
- isNoInit → bool
-
Whether the provider opts out of the global
providerInithook (@noInit).final - isSettable → bool
-
final
- name → String
-
final
- notifierType → String
-
no setter
- nullableStateType → String
-
Returns the nullable version of stateType.
If stateType already ends with '?', returns it as-is to avoid 'Type??'.
no setter
- options → RiverpodCraftOptions
-
The error type parameter (
F) for generated state/notifiers: the configurederror_mapper's return type, orObjectby default. Configuration for this build, threaded in at collection time.final - pageKeyType → String
-
The page-key type of a paged provider (the type of the
pageparam).intfor page-number pagination, or a nullable type (e.g.String?) for cursor pagination.final -
params
→ List<
ParameterInfo> -
final
- providerVarName → String
-
no setter
-
publicMethods
→ List<
PublicMethod> -
final
- requiresRef → bool
-
final
- returnName → String
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- stateType → String
-
no setter
- type → ProviderType
-
final
Methods
-
build(
) → String -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited